#include "EventBuilder.h"
#include "Buffer.h"
#include <algorithm>
#include <iostream>

EventBuilder::EventBuilder(double rate,
			   Buffer & b1, Buffer & b2, Buffer & b3) :
  _rate(rate), _b1(&b1), _b2(&b2), _b3(&b3), _idle(true) {
}

EventBuilder::~EventBuilder() {
}

double EventBuilder::daqTime() {
  unsigned int data = std::max(std::max(_b1->topData(), _b2->topData()), _b3->topData());
  return data / _rate;
}

bool EventBuilder::idle() { return _idle; }

void EventBuilder::setBusy() { _idle = false; }

bool EventBuilder::build() {
  if(_b1->empty() || _b2->empty() || _b3->empty()) {
    std::cout << ">>> event build fail: empty buffers." << std::endl;
    _idle = true;
    return false;
  }
  unsigned int d1 = _b1->pop();
  unsigned int d2 = _b2->pop();
  unsigned int d3 = _b3->pop();
  std::cout << ">>> event build, data: " << d1 << ", " << d2 << ", " << d3 << std::endl;
  _idle = (_b1->empty() || _b2->empty() || _b3->empty());
  return true;
}
