#include "Scheduler.h"
#include "Buffer.h"
#include "EventBuilder.h"
#include "Detector.h"
#include "Random.h"
#include <iostream>

class TestTask1 : public Task {
public:
  TestTask1(double t) : Task(t) { }
  virtual ~TestTask1() { }
  virtual void action() { std::cout << "action 1, t = " << time() << std::endl; }
};

class TestTask2 : public Task {
public:
  TestTask2(double t) : Task(t) { }
  virtual ~TestTask2() { }
  virtual void action() { std::cout << "action 2, t = " << time() << std::endl; }
};

int main() {
  Scheduler & sch = Scheduler::instance();
  sch.push(new TestTask1(10));
  sch.push(new TestTask2(1));
  sch.push(new TestTask1(7));
  sch.push(new TestTask2(4));

  sch.action();
  sch.action();
  sch.action();
  sch.action();

  Buffer buf(30);
  std::cout << "push 4: " << buf.push(4) << std::endl;
  std::cout << "push 4: " << buf.push(4) << std::endl;
  std::cout << "push 4: " << buf.push(4) << std::endl;
  std::cout << "pop: " << buf.pop() << std::endl;
  std::cout << "push 4: " << buf.push(4) << std::endl;

  Random::seed(12436);
  Buffer b1(20), b2(20), b3(20);
  EventBuilder b(5.0, b1, b2, b3);
  Detector det(1,
	       7, 6, 5,
	       2, 2, 2,
	       b1, b2, b3, b);

  double now = 0;
  for(int i = 0; i < 50; i++)
    now = det.event(now);

  sch.run();
  
  return 0;
}
